#[repr(u64)]pub enum CetShadowStacks {
Defer = 0,
AlwaysOn = 1,
AlwaysOff = 2,
Strict = 3,
}Expand description
CET user shadow-stack modes.
Runtime support depends on the Windows release, processor architecture, hardware capabilities, and child executable. Representability here does not imply that the current host accepts the policy.
Variants
Defer = 0
Defer to the child.
AlwaysOn = 1
Enable user shadow stacks.
AlwaysOff = 2
Disable user shadow stacks.
Strict = 3
Enable strict shadow-stack mode.